@@ -58,10 +58,11 @@ plot(c(floor(min(x$lon)),ceiling(max(x$lon))),
      c(floor(min(x$lat)),ceiling(max(x$lat))),
      type="n",main=title.1,sub=sub,
      xlab="Longitude",ylab="Latitude")
-if (range(x$lon)[2]-range(x$lon)[1] > 360) {
-  xy.cont <- COn0E65N(lon.cont, lat.cont)
-  addland(lon=xy.cont$x,lat=xy.cont$y)
-} else addland()
+#if (range(x$lon)[2]-range(x$lon)[1] > 360) {
+#  xy.cont <- COn0E65N(lon.cont, lat.cont)
+#  addland(lon=xy.cont$x,lat=xy.cont$y)
+#} else
+addland()
 grid()
 col.tab <- col[1:length(id)]
 neofs <- length(x$var)
